<?php

namespace App\Http\Controllers;

use App\Helpers\Helper\Helper;
use Illuminate\Http\Request;
use App\Models\Auction;
use App\Models\AuctionSetting;
use App\Models\AuctionTransection;
use App\Models\IsoStage;
use App\Models\Message;
use App\Models\ReturnAuctionLog;
use App\Models\User;
use App\Notifications\MessageNotification;
use Illuminate\Support\Facades\Redis;

class AuctionController extends Controller
{
    //

    public function index()
    {
        $data['auctions'] = Auction::where('status', 1)->latest()->get();
        $data['title'] = "Auctions";
        $data['auctionsActive'] = 'active';
        return view(Helper::theme() . 'user.auction.index')->with($data);
    }
    public function create()
    {
        $data['title'] = 'Auction';
        $data['createAuctionActive'] = 'active';
        return view(Helper::theme() . 'user.auction.create')->with($data);
    }

    public function store(Request $request)
    {


        $validated = $request->validate([
            'tokens' => 'required',
            'base_price' => 'required',
            'start_date' => "required|after_or_equal:today",
            'end_date' => 'required | after:start_date',
            'description' => 'required'

        ]);

        
        $hasAnyActiveAuction = Auction::where('auction_user_id', auth()->user()->id)->where('status', 1)->first();



        if ($hasAnyActiveAuction) {
            return redirect()->back()->with('error', 'You have already running a auction');
        }


        $data = $request->except('_token');

        if (!IsoStage::where('status', 1)->latest()->first()) {
            return redirect()->back()->with('error', 'No action active yet!');
        }
        $activeStage = IsoStage::where('status', 1)->latest()->first()->token_base_price;

        $data['base_price'] = $activeStage + (($activeStage / 100) * $request->base_price);

        $available_token = auth()->user()->ico_token;

        if ($available_token >= $request->tokens) {

            $data['code'] = strtolower(Helper::config()->appname) . '-' . $this->generateRandomCode(12);
            $data['auction_user_id'] = auth()->user()->id;
            $user = User::find(auth()->user()->id);
            $user->ico_token = $user->ico_token - $request->tokens;
            $user->save();
            Auction::create($data);

            return redirect()->route('user.auction.index')->with('success', 'Auction created successfully');
        } else {
            return redirect()->back()->with('error', 'You have not enough tokens');
        }
    }

    protected function generateRandomCode($length)
    {

        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $code = '';
        for ($i = 0; $i < $length; $i++) {
            $code .= $characters[rand(0, strlen($characters) - 1)];
        }
        return $code;
    }

    public function details($code)
    {
        $data['auction'] = Auction::where('code', $code)->first();
        $data['title'] = 'Auction';
        return view(Helper::theme() . 'user.auction.details')->with($data);
    }

    public function auctionTransectionStore(Request $request)
    {
        $setting = AuctionSetting::first();


        $hasAuction = Auction::find($request->auction_id);

        if (!$hasAuction) {
            return redirect()->back()->with('error', 'No auction available');
        }

        if ($hasAuction->tokens < $request->token) {
            return redirect()->back()->with('error', 'Not enough token available');
        }

        $buyer = User::find(Auth()->user()->id);

        $realPrice =  $hasAuction->base_price * $request->token;
        $data['total_amount'] = $realPrice - ($realPrice * ($setting->auction_sell_percantage / 100));

        if ($buyer->balance < $data['total_amount']) {
            return redirect()->back()->with('error', 'You have not enough balance. please deposit');
        }


        $data['auction_id'] = $hasAuction->id;
        $data['seller_id'] = $hasAuction->auction_user_id;
        $data['buyer_id'] = Auth()->user()->id;
        $data['token'] = $request->token;
        $data['base_price'] = $hasAuction->base_price;


        AuctionTransection::create($data);

        $buyer->balance = $buyer->balance - $realPrice;
        $buyer->ico_token = $buyer->ico_token + $data['token'];
        $buyer->save();

        $seller = User::find($hasAuction->auction_user_id);
        $seller->balance = $seller->balance + $data['total_amount'];
        $seller->save();

        $hasAuction->tokens = $hasAuction->tokens - $request->token;
        $hasAuction->save();

        if ($hasAuction->tokens == 0) {
            $hasAuction->status = 0;
            $hasAuction->save();
        }
        $symbol = Helper::token()->token_symbol;
        $sllerInfo['subject'] = 'token purchases';
        $sellerInfo['email'] = $seller->email;
        $sellerInfo['message'] = "{$buyer->username} is purchase your {$data['token']} {$symbol}";
        Helper::commonMail($sellerInfo);


        $bueyerInfo['subject'] = 'token purchases';
        $bueyerInfo['email'] = $buyer->email;
        $bueyerInfo['message'] = "successfully you purchased {$data['token']} {$symbol}";
        Helper::commonMail($bueyerInfo);


        return redirect()->back()->with('success', 'successfully completed');
    }




    public function settingStore(Request $request)
    {
        $setting = AuctionSetting::first();
        $validated = $request->validate([
            'auction_sell_percantage' => 'required | gt:0',
            'auction_refund_percantage' => 'required | gt:0'
        ]);
        if ($setting) {
            $setting->auction_sell_percantage = $request->auction_sell_percantage;
            $setting->auction_refund_percantage = $request->auction_refund_percantage;
            $setting->save();

            $msg = 'Setting updated successfully';
        } else {
            $s = new AuctionSetting();
            $s->auction_sell_percantage = $request->auction_sell_percantage;
            $s->auction_refund_percantage = $request->auction_refund_percantage;
            $s->save();

            $msg = 'Setting Created Successfully';
        }

        return redirect()->back()->with('success', $msg);
    }


    public function auctionWithdraw($code)
    {
        $auction = Auction::where('code', $code)->where('status', 1)->first();

        $auctionSetting = AuctionSetting::first();
        $stage = IsoStage::where('status', 1)->first();

        if (!$stage) {
            $stage = IsoStage::latest()->first();
        }

        $tokens = $auction->tokens;
        $percentage = ceil(($auctionSetting->auction_refund_percantage / 100) * $auction->tokens);
        $refund = $tokens - $percentage;

        $return = $tokens - $refund;
        $stage->used_token = $stage->used_token - $percentage;
        $stage->save();

        $auction->status = 0;
        $auction->save();

        $user = User::find($auction->auction_user_id);
        $user->ico_token = $user->ico_token + $refund;
        $user->save();

        ReturnAuctionLog::create([
            'stage_id' => $stage->id,
            'auction_id' => $auction->id,
            'tokens' => $percentage
        ]);

        return redirect()->route('user.dashboard')->with('success', 'auction withdraw successfully');
    }


    function auctionMessage($code)
    {

        

        $data['title'] = 'Messages';

        $auction = Auction::where('auction_user_id', auth()->id())->where('code', $code)->firstOrFail();


        if(request()->ajax()){

            $data['auction'] = Auction::where('auction_user_id', auth()->id())->where('code', $code)->firstOrFail();

            $data['messages'] = Message::where('auction_id', $auction->id)->where(function($item){
                $item->where('sender_id', request()->customer)->orWhere('reciever_id', request()->customer);
            })->get();

            $ids = Message::where('auction_id', $auction->id)->where(function($item){
                $item->where('sender_id', request()->customer)->orWhere('reciever_id', request()->customer);
            })->pluck('id')->toArray();

            $messageIds = Message::where('auction_id', $auction->id)->where('sender_id', '!=', auth()->id())->pluck('sender_id')->toArray();

            $data['customers'] = User::whereIn('id', $messageIds)->latest()->get();

            Message::whereIn('id', $ids)->orderBy('id', 'asc')->update(['read_at' => now()]);

            return view(Helper::theme() . 'user.auction.customer_ajax')->with($data);
        }


        $data['messages'] = Message::where('auction_id', $auction->id)->where(function($item){
            $item->where('sender_id', request()->customer)->orWhere('reciever_id', request()->customer);
        })->get();

        $ids = Message::where('auction_id', $auction->id)->where(function($item){
            $item->where('sender_id', request()->customer)->orWhere('reciever_id', request()->customer);
        })->pluck('id')->toArray();

        $messageIds = Message::where('auction_id', $auction->id)->where('sender_id', '!=', auth()->id())->pluck('sender_id')->toArray();

        $data['customers'] = User::whereIn('id', $messageIds)->latest()->get();
        $data['auction'] = $auction;

        return view(Helper::theme() . 'user.chat')->with($data);
    }

    function auctionMessageStore(Request $request){

        $request->validate([
            'message' => 'required'
        ]);

        $message = Message::create([
            'sender_id' => auth()->id(),
            'reciever_id' => $request->customer,
            'message' => $request->message,
            'auction_id' => $request->auction
        ]);

        $user = User::find($request->customer);

        if($user){
            $user->notify(new MessageNotification($message));
        }

    }
}
