<?php

namespace App\Http\Controllers\Backend;

use App\Helpers\Helper\Helper;
use App\Http\Controllers\Controller;
use App\Models\Gateway;
use App\Models\IsoCurrency;
use Illuminate\Http\Request;

class IcoCurrencyController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        //
        $data['title'] = "Currency";
        $data['currencies'] = IsoCurrency::search($request->search)->latest()->paginate(Helper::pagination());
        
        return view('backend.iso_currency.index')->with($data);
    }

    public function create()
    {
    
        $data['title'] = "Currency";
        $data['gatways'] = Gateway::where('status',1)->get();
        return view('backend.iso_currency.create')->with($data);
    }

    public function store(Request $request)
    {
        //
        $data = $request->except('_token');
        $validated = $request->validate([
            'name' => 'required | unique:iso_currencies',
            'rate' => 'required | gt:0',
            'gatway_id' => 'required',
            'image' => 'required | mimes:jpg,png,jpeg',
            'currency_type' => 'required'
        ]);
        $data['image'] = Helper::saveImage($request->image, Helper::filePath('currency'),$request->image);
        IsoCurrency::create($data);
        return redirect()->route('admin.ico-currency.index')->with('success','Currency created successfully');
    }

  
    public function show($id)
    {
        return abort(404);
    }

    public function edit($id)
    {

        $data['currency'] = IsoCurrency::find($id);
        $data['title'] = 'Edit Currency';
        $data['gatways'] = Gateway::where('status',1)->get();
        return view('backend.iso_currency.edit')->with($data);
    }

    public function update(Request $request, $id)
    {
     
        $currency = IsoCurrency::find($id);
        
        $data = $request->except('_token','_method','update_image');


        $validated = $request->validate([
            'name' => 'required',
            'rate' => 'required | numeric | gt:0',
            'gatway_id' => 'required',
            'currency_type' => 'required'
        ]);


        if($request->hasFile('update_image')){

            $validated = $request->validate([
                "update_image" => 'required | mimes:jpg,jpeg,png'
            ]);

            $data['image'] = Helper::saveImage($request->update_image, Helper::filePath('currency'),$request->update_image);
        }
        $currency->update($data);
        return redirect()->route('admin.ico-currency.index')->with('success','Currency updated successfully');
    }


    public function destroy($id)
    {
       
        IsoCurrency::find($id)->delete();
        return redirect()->route('admin.ico-currency.index')->with('success','Currency deleted successfully');
    }
}
