<?php

namespace App\Http\Controllers\Backend;

use App\Helpers\Helper\Helper;
use App\Http\Controllers\Controller;
use App\Models\IcoSetting;
use App\Models\IsoCurrency;
use App\Models\IsoStage;
use App\Models\AuctionSetting;
use App\Models\Whitepaper;
use Illuminate\Http\Request;


class IsoStageController extends Controller
{

    public function index()
    {
        $data['title'] = 'Stage List';
        $data['stages'] = IsoStage::latest()->paginate(Helper::pagination());
        return view('backend.stage.index')->with($data);
        
    }


    public function create()
    {
        $data['title'] = 'Stage';
        return view('backend.stage.create')->with($data);
    }

    public function store(Request $request)
    {
        
     
        $validated = $request->validate([
            'stage_name' => 'required | unique:iso_stages',
            'token_issues' => 'required | numeric | gt:0',
            'token_base_price' => 'required',
            'bonus' => 'nullable|numeric|gt:0',
            'soft_cap' => 'required',
            'hard_cap' => 'required',
            'start_date' => 'required|after_or_equal:today',
            'end_date' => 'required | after:start_date' 
        ]);

        $setting = IcoSetting::first();
        $auctionsetting = AuctionSetting::first();


        if(!$setting)
        {
            return back()->with('error','Ico setting not updated');
        }

        if(!$auctionsetting){
            return back()->with('error','auction setting not updated');
        }

        $stage = new IsoStage();
        $stage->stage_name = $request->stage_name;
        $stage->token_issues = $request->token_issues;
        $stage->token_base_price = $request->token_base_price;
        $stage->bonus = $request->bonus;
        $stage->soft_cap = $request->soft_cap;
        $stage->hard_cap = $request->hard_cap;
        $stage->start_date = $request->start_date;
        $stage->end_date = $request->end_date;
        $stage->status = $request->status;
        $created = $stage->save();

        if($created){

            if($stage->status == true){
                IsoStage::where('id','!=',$stage->id)->update(['status'=>0]);
            }
        }
       
        return redirect()->route('admin.ico-stage.index')->with('success','Stage created successfully');
    }


    public function show($id)
    {
     
        $data['title'] = 'Stage Details';
        $data['stage'] = IsoStage::find($id);
        return view('backend.stage.show')->with($data);
        
    }


    public function edit($id)
    {
  
        $data['title'] = 'Stage';
        $data['stage'] = IsoStage::find($id);
        return view('backend.stage.edit')->with($data);
    }


    public function update(Request $request, $id)
    {
        

        $validated = $request->validate([
            'stage_name' => 'required',
            'token_issues' => 'required | numeric | gt:0',
            'bonus' => 'nullable|numeric|gt:0',
            'token_base_price' => 'required',
            'soft_cap' => 'required',
            'hard_cap' => 'required',
            'start_date' => 'required',
            'end_date' => 'required | after:start_date' 
        ]);

        $stage = IsoStage::find($id);
        $data = $request->except('_token','_method');
        $stage->update($data);
        
        if($request->status == 1){
             IsoStage::where('id','!=',$id)->update(['status'=>0]);
        }
        
        
        return redirect()->route('admin.ico-stage.index')->with('success','Stage updated successfully');
    }

    

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function setting()
    {
        $data['title'] = 'ICO Setting';
        $data['setting'] = IcoSetting::first();
        $data['currencies'] = IsoCurrency::where('status',1)->latest()->get();
        $data['auction_setting'] = AuctionSetting::first();
        $data['attachments'] = Whitepaper::latest()->paginate(Helper::pagination());
        return view('backend.stage.setting')->with($data);
    }

    public function settingStore(Request $request)
    {
        $setting = IcoSetting::first();
        $validated = $request->validate([
            'token_name' => 'required',
            'token_symbol' => 'required',
            'currency_id' => 'required'
        ]);
        if($setting){
                $setting->token_name = $request->token_name;
                $setting->token_symbol = $request->token_symbol;
                $setting->currency_id = $request->currency_id;
                $setting->save();

                $msg = 'Setting updated successfully';
        }else{
            $s = new IcoSetting();
            $s->token_name = $request->token_name;
            $s->token_symbol = $request->token_symbol;
            $s->currency_id = $request->currency_id;
            $s->save();

            $msg = 'Setting Created Successfully';
        }

        return redirect()->back()->with('success',$msg);
    }


    public function allStages()
    {
        $data['stageActive'] = 'active';
        $data['stages'] = IsoStage::orderBy('status','desc')->paginate(Helper::pagination());
        return view(Helper::theme().'user.stage.index')->with($data);
    }
}
