<?php

namespace App\Http\Controllers\backend;

use App\Helpers\Helper\Helper;
use App\Http\Controllers\Controller;
use App\Models\Admin;
use App\Models\Configuration;
use App\Models\Gateway;
use App\Models\GeneralSetting;
use App\Models\IsoStage;
use App\Models\Payment;
use App\Models\Template;
use App\Models\Transaction;
use App\Models\User;
use App\Models\UserToken;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class PaymentController extends Controller
{
    public function payment(Request $request)
    {

        $dates = [];
        if($request->dates){
            $dates = array_map(function($q){
                return Carbon::parse($q);
            }, explode('-', $request->dates));
        }

        $type = $request->type === 'online' ? 1 : 0;

        $payment = Payment::query();

        if ($type) {
            $payment->onlinePayment();
        } else {
            $payment->offlinePayment();
        }

        $data['title'] = 'Manage payments';

        $data['payments'] = $payment->when($request->dates, function($q) use ($dates){
            $q->whereBetween('created_at', $dates);
        })->search($request->search)->latest()->with('plan', 'gateway', 'user')->paginate(Helper::pagination());

        return view('backend.payments.index')->with($data);
    }

    public function details($id)
    {
        $data['payment'] = Payment::findOrFail($id);

        $data['title'] = 'Payment Details';

        return view('backend.payments.details')->with($data);
    }


    public function accept(Request $request)
    {
        $payment = Payment::where('trx', $request->trx)->firstOrFail();
        $plan = IsoStage::find($payment->plan_id);
        $general = Configuration::first();
    
        $gateway = $payment->gateway;
      
        $payment->status = 1;
        $payment->tokens += $plan->bonus ?? 0;

        $payment->save();
        
        $stage = IsoStage::find($payment->plan_id);
        $stage->used_token = $stage->used_token + $payment->tokens + $stage->bonus;
        $stage->save();

        UserToken::create([
            'user_id' => $payment->user_id,
            'stage_id' => $payment->plan_id,
            'tokens' => $payment->tokens,
            'payment_id' => $payment->id
        ]);


        $user = User::find($payment->user_id);
        $user->ico_token = $user->ico_token + $payment->tokens;
        $user->save();


        Helper::referMoney($payment->user_id, $payment->user->refferedBy, 'invest', $payment->amount);

        $admin = Admin::where('type', 'super')->first();

        $data = [
            'plan_id' => $payment->plan_id,
            'user_id' => $payment->user_id,
            'expired' => $payment->plan_expired_at
        ];



        Transaction::create([
            'trx' => $payment->trx,
            'amount' => $payment->amount,
            'details' => 'Payment Successfull',
            'charge' => $gateway->charge,
            'type' => '-',
            'user_id' => $payment->user_id,
            'currency' => $gateway->parameter->gateway_currency ?? Helper::config()->currency,
            'convert_rate' => $gateway->rate ?? 1
        ]);

        $templete = Template::where('name', 'payment_confirmed')->where('status',1)->first();

        if($templete){
            Helper::fireMail([
                'username'=>$payment->user->username,
                'email' => $payment->user->email,
                'app_name' => $general->app_name,
                'trx' => $payment->trx, 
                'amount' => $payment->amount, 
                'charge' => number_format($gateway->charge, 4), 
                'plan' => $payment->plan->name, 
                'currency' => $general->currency
            ], $templete);
        }




        return redirect()->back()->with('success', "Payment Confirmed Successfully");
    }

    public function reject(Request $request)
    {

        $payment = Payment::where('trx', $request->trx)->firstOrFail();

        $general = Configuration::first();

        $gateway = $payment->gateway;

        $payment->rejection_reason = $request->reason;
        $payment->status = 3;

        $payment->save();

        $templete = Template::where('name', 'payment_rejected')->where('status',1)->first();

        if($templete){
            Helper::fireMail([
                'username'=>$payment->user->username,
                'email' => $payment->user->email,
                'app_name' => $general->app_name,
                'trx' => $payment->trx, 
                'amount' => $payment->amount, 
                'charge' => number_format($gateway->charge, 4), 
                'plan' => $payment->plan->name, 
                'currency' => $general->currency
            ], $templete);
        }

        return back()->with('success', "Payment Rejected Successfully");
    }

    
}
