<?php

namespace App\Http\Controllers;

use App\Helpers\Helper\Helper;
use App\Models\AuctionTransection;
use App\Models\Deposit;
use App\Models\Payment;
use App\Models\PlanSubscription;
use App\Models\ReferralCommission;
use App\Models\Transaction;
use App\Models\UserToken;
use App\Models\Withdraw;
use Illuminate\Http\Request;

class LogController extends Controller
{
    public function depositLog(Request $request)
    {
        $data['title'] = "Deposit Log";
        $data['depositLog'] = 'active';
        $data['activeSubMenu'] = 'submenu-active';
        $data['deposits'] = Deposit::when($request->trx, function ($item) use ($request) {
            $item->where('trx', $request->trx);
        })->when($request->date, function ($item) use ($request) {
            $item->whereDate('created_at', $request->date);
        })
            ->where('user_id', auth()->id())
            ->latest()->with('user')
            ->whereIn('status', [1, 2, 3])
            ->latest()
            ->with('gateway')
            ->paginate(Helper::pagination());

        return view(Helper::theme() . 'user.log.deposit_log')->with($data);
    }


    public function allWithdraw(Request $request)
    {
        $data['title'] = 'All withdraw';
        $data['withdrawLog'] = 'active';
        $data['activeSubMenu'] = 'submenu-active';

        $data['withdrawlogs'] = Withdraw::when($request->trx, function ($item) use ($request) {
            $item->where('trx', $request->trx);
        })->when($request->date, function ($item) use ($request) {
            $item->whereDate('created_at', $request->date);
        })->where('user_id', auth()->id())->latest()->with('withdrawMethod')->paginate(Helper::pagination());

        return view(Helper::theme() . 'user.withdraw.withdraw_log')->with($data);
    }

    public function pendingWithdraw()
    {
        $data['title'] = 'Pending withdraw';

        $data['withdrawlogs'] = Withdraw::where('user_id', auth()->id())->where('status', 0)->latest()->with('withdrawMethod')->paginate(Helper::pagination());

        return view(Helper::theme() . 'user.withdraw.withdraw_log')->with($data);
    }

    public function completeWithdraw()
    {
        $data['title'] = 'Complete withdraw';

        $data['withdrawlogs'] = Withdraw::where('user_id', auth()->id())->where('status', 1)->latest()->with('withdrawMethod')->paginate(10);

        return view(Helper::theme() . 'user.withdraw.withdraw_log')->with($data);
    }


    public function investLog(Request $request)
    {
        $data['title'] = 'Payment Log';
        $data['paymentActiveLog'] = 'active';
        $data['activeSubMenu'] = 'submenu-active';
        $data['investments'] = Payment::when($request->trx, function ($item) use ($request) {
            $item->where('trx', $request->trx);
        })->when($request->date, function ($item) use ($request) {
            $item->whereDate('created_at', $request->date);
        })->where('user_id', auth()->id())->whereIn('status', [1, 2, 3])->latest()->with('user', 'gateway')->paginate(Helper::pagination());

        return view(Helper::theme() . 'user.log.invest_log')->with($data);
    }


    public function transactionLog(Request $request)
    {
        $data['title'] = 'Transaction Log';
        $data['transactionLogActive'] = 'active';
        $data['activeSubMenu'] = 'submenu-active';
        $data['transactions'] = Transaction::with('user')->when($request->trx, function ($item) use ($request) {
            $item->where('trx', $request->trx);
        })->when($request->date, function ($item) use ($request) {
            $item->whereDate('created_at', $request->date);
        })->where('user_id', auth()->id())->latest()->with('user')->paginate(Helper::pagination());

        return view(Helper::theme() . 'user.log.transaction')->with($data);
    }

    public function commision(Request $request)
    {

        $data['title'] = 'Refferal Commission';
        
        $data['activeSubMenu'] = 'submenu-active';
        
        $data['commissionActive'] = 'active';

        $data['commison'] = ReferralCommission::when($request->date, function ($item) use ($request) {
            $item->whereDate('created_at', $request->date);
        })->where('commission_to', auth()->id())->latest()->with('whoGetTheMoney', 'whoSendTheMoney')->paginate(Helper::pagination());

        return view(Helper::theme() . 'user.log.commision_log')->with($data);
    }

  

    public function refferalLog()
    {
        $data['reference'] = auth()->user()->refferals;
        $data['title'] = 'Refferal Log';
        $data['refferalActive'] = 'active';
        return view(Helper::theme(). 'user.refferal')->with($data);
    }

    public function stage_log(Request $request)
    {
        $data['activeStageLog'] = 'active';
        $data['activeSubMenu'] = 'submenu-active';
        $data['title'] = 'Stage Log';
        $data['logs'] = UserToken::where('user_id',auth()->user()->id)
                        ->when($request->date,function ($item) use ($request){
                            $item->whereDate('created_at',$request->date);
                        })
                        ->latest()->paginate(Helper::pagination());


        return view(Helper::theme(). 'user.log.stage_log')->with($data);
    }


    public function auction_log(Request $request,$status)
    {
        
        $data['activeSubMenu'] = 'submenu-active';
        if($status == 'auction-sale' || $status == 'all'){

            $data['logs'] = AuctionTransection::where('seller_id',auth()->user()->id)->latest()
                            ->when($request->date,function ($item) use ($request){
                                $item->whereDate('created_at',$request->date);
                            })
                            ->paginate(Helper::pagination());
            $data['status'] = 'sale';
        }else{
            $data['logs'] = AuctionTransection::where('buyer_id',auth()->user()->id)
                            ->when($request->date,function ($item) use ($request){
                                $item->whereDate('created_at',$request->date);
                            })
                            ->latest()->paginate(Helper::pagination());
            $data['status'] = 'buy';
        }

        $data['activeAuctionLog'] = 'active';
        return view(Helper::theme(). 'user.log.auction_log')->with($data);

        
    }
}
