<?php
namespace App\Http\Controllers;

use App\Helpers\Helper\Helper;
use App\Http\Requests\UserProfile;
use App\Models\Message;
use App\Models\User;
use App\Notifications\MessageNotification;
use App\Services\UserDashboardService;
use App\Services\UserProfileService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class UserController extends Controller
{
    protected $profile, $dashboard;


    public function __construct(UserProfileService $profile, UserDashboardService $dashboard)
    {
        $this->profile = $profile;
        $this->dashboard = $dashboard;
    }

    public function dashboard()
    {
        $data = $this->dashboard->dashboard();
        $data['title'] = "Dashboard";
        $data['dashboardActive'] = 'active';
        return view(Helper::theme() . 'user.dashboard')->with($data);
    }

    public function user_visit_profile($username)
    {
        $data['user'] = User::where('username', $username)->first();
        $data['title'] = "Profile";

        if (!$data['user']) {
            return abort(404, 'invalid username');
        }
        return view(Helper::theme() . 'user.visit_profile')->with($data);
    }

    public function profile()
    {
        $data['title'] = 'Profile Edit';

        $data['user'] = auth()->user();
        $data['userProfileSettingActive'] = 'active';
        return view(Helper::theme() . 'user.setting.profile')->with($data);
    }

    public function profileUpdate(UserProfile $request)
    {

        $isSuccess = $this->profile->update($request);

        if ($isSuccess['type'] === 'success')
            return back()->with('success', $isSuccess['message']);
    }

    public function changePassword()
    {
        $title = 'Change Password';
        return view(Helper::theme() . 'user.setting.changepassword', compact('title'));
    }

    public function updatePassword(Request $request)
    {
        $request->validate([
            'oldpassword' => 'required|min:6',
            'password' => 'min:6|confirmed',
        ]);

        $user = User::find(auth()->id());

        if (!Hash::check($request->oldpassword, $user->password)) {
            return redirect()->back()->with('error', 'Old password do not match');
        } else {
            $user->password = bcrypt($request->password);

            $user->save();

            return redirect()->back()->with('success', 'Password Updated');
        }
    }



    function chat(Request $request)
    {
        $data['title'] = 'Message';

        $data['allMessages']  = Message::where('auction_id', $request->auction)->where(function($item){
            $item->where('sender_id', auth()->id())->orWhere('reciever_id', auth()->id());
        })->orderBy('id', 'asc')->get();

        if ($request->ajax()) {

            Message::where('auction_id', $request->auction)->where('reciever_id', auth()->id())->update(['read_at' => now()]);

            return view(Helper::theme().'user.chat_ajax')->with($data);
        }

        return view('front.default.client.chat')->with($data);
    }


    public function chatStore(Request $request)
    {
        $request->validate([
            'message' => 'required'
        ]);
        
        $message = Message::create([
            'sender_id' => auth()->id(),
            'reciever_id' => $request->id,
            'message' => $request->message,
            'auction_id' => $request->auction
        ]);

        $user = User::find($request->id);

        if($user){
            $user->notify(new MessageNotification($message));
        }
    }
}
