<?php

namespace App\Services;

use App\Helpers\Helper\Helper;
use App\Models\Configuration;
use Illuminate\Support\Facades\Artisan;

class ConfigurationService
{

    public function general($request)
    {

        if ($request->type == 'general') {

            if ($request->has('logo')) {

                $logo = 'logo' . '.' . $request->logo->getClientOriginalExtension();

                $request->logo->move(Helper::filePath('logo', true), $logo);
            }

            if ($request->has('icon')) {

                $icon = 'icon' . '.' . $request->icon->getClientOriginalExtension();

                $request->icon->move(Helper::filePath('icon', true), $icon);
            }
            
            if ($request->has('admin_login')) {

                $admin_login = 'admin_login' . '.' . $request->admin_login->getClientOriginalExtension();

                $request->admin_login->move(Helper::filePath('admin_login', true), $admin_login);
            }


            Configuration::updateOrCreate([
                'id' => 1
            ], [
                'appname' => $request->sitename,
                'signup_bonus' => $request->signup_bonus,
                'currency' => $request->site_currency,
                'logo' => isset($logo) ? ($logo ?? '') : Configuration::first()->logo,
                'favicon' => isset($icon) ? ($icon ?? '') : Configuration::first()->favicon,
                'color' =>  $request->primary_color ?? '',
                'withdraw_limit' => $request->withdraw_limit,
                'pagination' => $request->pagination_limit,
                'alert' => $request->alert,
                'decimal_precision' => $request->decimal_precision,
                'admin_login_image' => isset($admin_login) ? ($admin_login ?? '') : Configuration::first()->admin_login_image,
            ]);


            Helper::setEnv([
                'APP_TIMEZONE' => $request->timezone
            ]);

            Artisan::call('config:clear');
        } elseif ($request->type == 'api') {
            Configuration::updateOrCreate([
                'id' => 1
            ], [
                'recaptcha_key' => $request->recaptcha_key,
                'recaptcha_secret' => $request->recaptcha_secret,
                'allow_recaptcha' => $request->allow_recaptcha == 'on' ? 1 : 0,
                'tdio_url' => $request->tidio_url,
                'tdio_allow' => $request->tdio_allow === 'on' ? 1 : 0,

                'analytics_key' => $request->analytics_key,
                'analytics_status' => $request->analytics_status === 'on' ? 1 : 0,

                'allow_facebook' => $request->allow_facebook === 'on' ? 1 : 0,
                'allow_google' => $request->allow_google === 'on' ? 1 : 0,
            ]);


            Helper::setEnv([
                'NEXMO_KEY' => $request->sms_username,
                'NEXMO_SECRET' => $request->sms_password,
                'FACEBOOK_APP_ID' => $request->app_id,
                'FACEBOOK_SECRET' => $request->app_secret,
                'GOOGLE_APP_ID' => $request->google_app_id,
                'GOOGLE_SECRET' => $request->google_app_secret,
            ]);
        } elseif ($request->type == 'others') {
            Configuration::updateOrCreate([
                'id' => 1
            ], [
                'button_text' => $request->button_text,
                'cookie_text' => $request->cookie_text,
                'cookie_details' => $request->cookie_details,
                'allow_modal' => $request->allow_modal === 'on' ? 1 : 0,
                'seo_description' => $request->seo_description,
                'fonts' => $request->fonts,
                'seo_tags' => $request->seo_tags,
                'copyright' => $request->copyright
            ]);
        } elseif ($request->type == 'pref') {
            Configuration::updateOrCreate([
                'id' => 1
            ], [

                'preloader_status' => $request->preloader_status === 'on' ? 1 : 0,
                'reg_enabled' => $request->user_reg == 'on' ? 1 : 0,
                'is_email_verification_on' => $request->is_email_verification_on == 'on' ? 1 : 0,
                'is_sms_verification_on' => $request->is_sms_verification_on == 'on' ? 1 : 0,
                'is_allow_kyc' => $request->user_kyc == 'on' ? 1 : 0,

            ]);
        } else {

            $general = Configuration::first();

            $general->kyc = $request->kyc;

            $general->save();
        }
        return ['type' => 'success', 'message' => 'General setting has been updated.'];
    }
}
