<?php

namespace App\Services\Gateway;

use App\Helpers\Helper\Helper;
use App\Models\Deposit;
use App\Models\Gateway;
use App\Models\Payment as ModelsPayment;
use PayPal\Auth\OAuthTokenCredential;
use PayPal\Api\Amount;
use PayPal\Api\Payer;
use PayPal\Api\Payment;
use PayPal\Api\RedirectUrls;
use PayPal\Api\Transaction;
use PayPal\Api\PaymentExecution;
use PayPal\Rest\ApiContext;

class PaypalService
{
    protected static $apiContext;

    public function __construct()
    {
        static::$apiContext = new ApiContext(
            new OAuthTokenCredential(config('services.paypal.client_id'), config('services.paypal.client_secret'))
        );
        static::$apiContext->setConfig(config('services.paypal.settings'));
    }

    public static function process($request, $paypal, $totalAmount, $deposit)
    {

        $payer = new Payer();
        $payer->setPaymentMethod("paypal");

        // Set redirect URLs
        $redirectUrls = new RedirectUrls();
        $redirectUrls->setReturnUrl(route('user.payment.success',$paypal->id))
            ->setCancelUrl(route('home'));


        // Set payment amount
        $amount = new Amount();
        $amount->setCurrency($paypal->parameter->gateway_currency)
            ->setTotal($totalAmount);

        // Set transaction object
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setDescription("Transaction Number {$deposit->trx}");

        // Create the full payment object
        $payment = new Payment();
        $payment->setIntent('sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirectUrls)
            ->setTransactions(array($transaction));

         

        // Create payment with valid API context
        try {
            $payment->create(self::$apiContext);

            // Get PayPal redirect URL and redirect the customer
            $approvalUrl = $payment->getApprovalLink();

            // Redirect the customer to $approvalUrl
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            echo $ex->getCode();
            echo $ex->getData();
            die($ex);
        } catch (\Exception $ex) {
            die($ex);
        }

        return ['type' =>'success' , 'data' =>  $payment];
    }


    public function success()
    {
        $paypal = Gateway::where('name', 'paypal')->firstOrFail();

        if (session('type') == 'deposit') {
            $booking = Deposit::where('trx', session('trx'))->first();
        } else {
            $booking = ModelsPayment::where('trx', session('trx'))->first();
        }

       
        // Get payment object by passing paymentId
        $paymentId = $_GET['paymentId'];
        $payment = Payment::get($paymentId, static::$apiContext);
        $payerId = $_GET['PayerID'];

        // Execute payment with payer ID
        $execution = new PaymentExecution();
        $execution->setPayerId($payerId);

        try {
            // Execute payment
            $result = $payment->execute($execution, static::$apiContext);

            $transaction = $result->id;

            $transactionFee = json_decode($result)->transactions[0]->related_resources[0]->sale->transaction_fee->value / $paypal->rate;

            if ($result->state == 'approved') {

                Helper::paymentSuccess($booking, $transactionFee, $transaction);

                return ['type'=>'success', 'message'=>'Payment Successfully Done'];
            }
        } catch (\PayPal\Exception\PayPalConnectionException $ex) {
            echo $ex->getCode();
            echo $ex->getData();
            die($ex);
        } catch (\Exception $ex) {
            die($ex);
        }
    }
}
