<?php

namespace App\Services;

use App\Helpers\Helper\Helper;
use App\Models\Auction;
use App\Models\Deposit;
use App\Models\IsoStage;
use App\Models\Payment;
use App\Models\ReferralCommission;
use App\Models\Transaction;
use App\Models\ViewAdd;
use App\Models\Withdraw;
use App\Models\UserToken;
use App\Utility\Sections\Auth;
use App\Utility\Sections\Referral;
use Carbon\Carbon;
use DB;

class UserDashboardService
{
    public function dashboard()
    {
        $user = auth()->user();
        $data['totalbalance'] = $user->balance;
        $data['totalDeposit'] = $user->deposits()->where('status', 1)->sum('amount');
        $data['totalWithdraw'] = $user->withdraws()->where('status', 1)->sum('withdraw_amount');
        $data['totalPayments'] = $user->payments()->where('status', 1)->sum('amount');
        $data['totalSupportTickets'] = $user->tickets()->count();
        $data['user'] = $user;
        $data['transactions'] = $user->transactions()->latest()->with('user')->limit(3)->get();
        $data['totalCommission'] = ReferralCommission::where('commission_to', $user->id)->sum('amount');
        $data['stage'] = IsoStage::where('status',1)->first();
        $data['stages'] = IsoStage::orderBy('status','desc')->get();
        $data['payments'] = Transaction::where('user_id',auth()->user()->id)->latest()->limit(10)->get();
        $months = array();

       

        $click = collect([]);
        $earn = collect([]);
        $coin = collect([]);
        $period = now()->subMonths(12)->monthsUntil(now());
    
        for ($i = 0; $i <= 11; $i++) {
            $month = Carbon::today()->startOfMonth()->subMonth($i);
            array_push($months, $month->monthName);
            $click->push(0);
            $earn->push(0);
            $coin->push(0);
        }


        $coins = UserToken::where('user_id',$user->id)->select(DB::raw('count(*) as total'),DB::raw('sum(tokens) as sum'),DB::raw('MONTHNAME(created_at) as month'))->groupby('month')
                ->get();
   
        foreach($coins as $c)
        {
            $result = array_search($c->month, $months);
            $coin[$result] = $c->sum;
        }

       

        
        $data['click'] = $click;
        $data['earn'] = $earn;
        $data['months'] = $months;
        $data['coins'] = $coin;

        $data['auctions'] = Auction::where('auction_user_id','!=',$user->id)->where('status',1)->latest()->get();
       
        return $data;
    }
}
