@extends('backend.layout.master')

@section('content')
    <div class="main-content">
        <section class="section">
            <div class="section-header">
                <h1>{{ __($pageTitle) }}</h1>
            </div>

            <div class="row">

                <div class="col-12 col-md-12 col-lg-12">
                    <div class="card">
                        <div class="card-header">
                            <button class="btn btn-primary add"><i class="fa fa-plus"></i> {{ __('Add Currency') }}</button>
                        </div>
                        <div class="card-body p-0">
                            <div class="table-responsive">
                                <table class="table table-striped" id="table-2">
                                    <thead>
                                        <tr>
                                            <th>{{ __('Currency') }}</th>
                                            <th>{{ __('Rate') }}</th>
                                            <th>{{ __('Charge') }}</th>
                                            <th>{{ __('Status') }}</th>
                                            <th>{{ __('Action') }}</th>
                                        </tr>
                                    </thead>
                                    <tbody>

                                        @foreach ($currencies as $currency)
                                            <tr>

                                                <td><img src='{{ getFile('currency', $currency->image, true) }}' class="flagadmin"> {{ $currency->name }}</td>
                                               
                                                <td>{{ number_format($currency->rate,2) }}</td>
                                                <td>
                                                    <p>{{ number_format($currency->charge,2) }}</p>
                                                    <p>
                                                        @if($currency->charge_type)
                                                         <span class="badge badge-primary">{{__('Percent')}}</span>
                                                         @else
                                                         <span class="badge badge-primary">{{__('Fixed')}}</span>
                                                         @endif
                                                    </p>
                                                </td>
                                                <td>
                                                    @if($currency->status)
                                                    <span class="badge badge-success">{{__('Active')}}</span>
                                                    @else
                                                    <span class="badge badge-danger">{{__('Deactive')}}</span>
                                                    @endif


                                                </td>
                                                <td>
                                                    <button class="btn btn-primary btn-sm edit" data-currency="{{$currency}}" data-url="{{route('admin.currency.update', $currency)}}"><i class="fa fa-pen"></i></button>
                                                </td>
                                            </tr>
                                        @endforeach


                                    </tbody>
                                </table>
                            </div>
                        </div>

                        @if($currencies->hasPages())
                        <div class="card-footer">
                            {{$currencies->links()}}
                        </div>

                        @endif
                    </div>
                </div>
            </div>
        </section>
    </div>


    <div class="modal fade" id="add" tabindex="-1" role="dialog" aria-labelledby="modelTitleId" aria-hidden="true">
        <div class="modal-dialog modal-lg" role="document">
            <form action="{{ route('admin.currency.store') }}" method="post" enctype="multipart/form-data">
                @csrf
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">{{ __('Add Currency') }}</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <div class="container-fluid">
                            <div class="row">

                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Country name') }}</label>
                                    <select name="country" id="country" class="form-control">
                                        @foreach ($codes as $code)
                                            <option value="{{$code->country}}" data-code="{{$code->currency_code}}">{{$code->country}}</option>
                                        @endforeach
                                    </select>
                                   
                                </div>


                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Currency name') }}</label>
                                    <input type="text" name="name" class="form-control" required id="currency" readonly>
                                </div>

                                <div class="form-group col-md-6">
                                    <label>{{ __('Currency Rate') }}</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <div class="input-group-text">
                                                1 {{ $general->site_currency }} =
                                            </div>
                                        </div>
                                        <input type="text" class="form-control" name="rate">
                                        <div class="input-group-append">
                                            <div class="input-group-text currency">

                                            </div>
                                        </div>
                                    </div>
                                </div>

                               

                                <div class="form-group col-md-6">
                                    <label>{{ __('Charge') }}</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <div class="input-group-text currency">

                                            </div>
                                        </div>
                                        <input type="text" class="form-control" name="charge">
                                        <select class="custom-select" id="inputGroupSelect01" name="type">
                                            <option selected value="">{{ __('Select Charge Type') }}</option>
                                            <option value="0">{{ __('Fixed') }}</option>
                                            <option value="1">{{ __('Percent') }}</option>

                                        </select>
                                    </div>
                                </div>

                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Status') }}</label>
                                    <input type="checkbox" data-toggle="toggle" data-on="Active" data-off="Disable"
                                        data-onstyle="success" data-offstyle="danger" name="status">
                                </div>


                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Image') }}</label>
                                    <input type="file" name="image" class="form-control">
                                </div>


                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">{{ __('Close') }}</button>
                        <button type="submit" class="btn btn-primary">{{ __('Save') }}</button>
                    </div>
                </div>
            </form>
        </div>
    </div>


    <div class="modal fade" id="edit" tabindex="-1" role="dialog" aria-labelledby="modelTitleId" aria-hidden="true">
        <div class="modal-dialog modal-lg" role="document">
            <form action="" method="post" enctype="multipart/form-data">
                @csrf
                @method('PUT')
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">{{ __('Update Currency') }}</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <div class="container-fluid">
                            <div class="row">

                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Country name') }}</label>
                                    <select name="country" id="country_edit" class="form-control">
                                        @foreach ($codes as $code)
                                            <option value="{{$code->country}}" data-code="{{$code->currency_code}}">{{$code->country}}</option>
                                        @endforeach
                                    </select>
                                   
                                </div>


                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Currency name') }}</label>
                                    <input type="text" name="name" class="form-control" required id="currency_edit">
                                </div>

                                <div class="form-group col-md-6">
                                    <label>{{ __('Currency Rate') }}</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <div class="input-group-text">
                                                1 {{ $general->site_currency }} =
                                            </div>
                                        </div>
                                        <input type="text" class="form-control" name="rate">
                                        <div class="input-group-append">
                                            <div class="input-group-text currency_edit">

                                            </div>
                                        </div>
                                    </div>
                                </div>

                                

                                <div class="form-group col-md-6">
                                    <label>{{ __('Charge') }}</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <div class="input-group-text currency_edit">

                                            </div>
                                        </div>
                                        <input type="text" class="form-control" name="charge">
                                        <select class="custom-select" id="inputGroupSelect01" name="type">
                                            <option selected value="">{{ __('Select Charge Type') }}</option>
                                            <option value="0">{{ __('Fixed') }}</option>
                                            <option value="1">{{ __('Percent') }}</option>

                                        </select>
                                    </div>
                                </div>

                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Status') }}</label>
                                    <input type="checkbox" data-toggle="toggle" data-on="Active" data-off="Disable"
                                        data-onstyle="success" data-offstyle="danger" name="status">
                                </div>


                                <div class="form-group col-md-6">
                                    <label for="">{{ __('Image') }}</label>
                                    <input type="file" name="image" class="form-control">
                                </div>


                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">{{ __('Close') }}</button>
                        <button type="submit" class="btn btn-primary">{{ __('Save') }}</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
@endsection

@push('style')
    <style>
        .toggle {
            width: 100% !important;
        }

        .flagadmin{
            max-width: 50px;
            margin-right: 10px;
        }
    </style>
@endpush

@push('script')
    <script>
        $(function() {
            'use strict'

            $('#currency').val($('#country option:nth-child(1)').data('code'))
            $('.currency').text($('#country option:nth-child(1)').data('code'))

            $('#country').on('change', function(){
                $('#currency').val($('#country option:selected').data('code'))
                $('.currency').text($('#country option:selected').data('code'))
            })
            
            $('#country_edit').on('change', function(){
                $('#currency_edit').val($('#country_edit option:selected').data('code'))
                $('.currency_edit').text($('#country_edit option:selected').data('code'))
            })

            $('.add').on('click', function() {
                const modal = $('#add');

                modal.modal('show')
            })

            $('#currency').on('keyup', function() {
                $('.currency').text($(this).val())
            })  
            
            
            $('#currency_edit').on('keyup', function() {
                $('.currency_edit').text($(this).val())
            })

            $('.edit').on('click', function(){
                const modal = $('#edit');

                modal.find('input[name=name]').val($(this).data('currency').name)
                modal.find('.currency_edit').text($(this).data('currency').name)
                modal.find('input[name=rate]').val(parseFloat($(this).data('currency').rate).toFixed(2))
                modal.find('input[name=charge]').val(parseFloat($(this).data('currency').charge).toFixed(2))
                modal.find('select[name=type]').val($(this).data('currency').charge_type)
                modal.find('select[name=country]').val($(this).data('currency').country)
                if($(this).data('currency').status){
                    modal.find('input[name=status]').bootstrapToggle('on');
                }else{
                    modal.find('input[name=status]').bootstrapToggle('off');
                }

                modal.find('form').attr('action', $(this).data('url'))

                modal.modal('show')
            })
        })
    </script>
@endpush
