<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">

    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <meta http-equiv="X-UA-Compatible" content="ie=edge">

    <meta name="keywords" content="{{ implode(',', $page->seo_keywords ?? Config::config()->seo_tags) }} ">
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <title>{{ Config::config()->appname }}</title>

    <link rel="shortcut icon" type="image/png" href="{{ Config::getFile('icon', Config::config()->favicon, true) }}">

    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'lib/bootstrap.min.css') }}">

    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'all.min.css') }}">

    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'line-awesome.min.css') }}">
    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'lib/basictable.min.css') }}">
    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'lib/dots.css') }}">
    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'chat/chat.css') }}">
    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'lib/glightbox.min.css') }}">

    @if (Config::config()->alert === 'izi')
        <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'izitoast.min.css') }}">
    @elseif(Config::config()->alert === 'toast')
        <link href="{{ Config::cssLib('frontend', 'toastr.min.css') }}" rel="stylesheet">
    @else
        <link href="{{ Config::cssLib('frontend', 'sweetalert.min.css') }}" rel="stylesheet">
    @endif

    @stack('external-css')

    <link rel="stylesheet" href="{{ Config::cssLib('frontend', 'main.css') }}">

    @stack('style')

    @php
        $heading = optional(Config::config()->fonts)->heading_font_family;
        $paragraph = optional(Config::config()->fonts)->paragraph_font_family;
    @endphp


    <style>
        :root {
            --clr-main: <?=Config::config()->color[Config::config()->theme] ?? '#9c0ac1' ?>;
            --h-font: <?=$heading ?>;
            --p-font: <?=$paragraph ?>;
        }
    </style>

</head>

<body class="user-pages-body">

    @include(Config::theme() . 'layout.loading')
    @include(Config::theme() . 'layout.sidebar');


    <header class="user-header">
        <a href="{{ route('home') }}" class="sp_site_logo">
            <img src="{{ Config::getFile('logo', Config::config()->logo, true) }}" alt="image">
        </a>
        
        <div class="lang-select grad-border-btn ms-auto me-sm-3 me-2">
            <i class="las la-globe"></i>
            <select class="change-lang">
                @foreach (Config::languages() as $language)
                        <option value="{{ $language->code }}" {{ Config::languageSelection($language->code) }}>
                            {{ __(ucwords($language->name)) }}
                        </option>
                @endforeach
            </select>
        </div>

        @if (auth()->user()->unreadNotifications->count() > 0)
            <div class="dropdown me-sm-3 me-2">
                <button class="dropdown-toggle" type="button" data-bs-toggle="dropdown" aria-expanded="false">
                    <i class="fas fa-bell"></i>
                </button>
                <ul class="dropdown-menu noti-dropdown">
                    @foreach (auth()->user()->unreadNotifications as $noti)
                        <li class="single-noti">
                            <a class="dropdown-item d-flex gap-3 align-items-center" href="{{$noti->data['url']}}">
                                <i class="las la-envelope"></i>
                                {{ $noti->data['message'] }}
                            </a>
                        </li>
                    @endforeach
                </ul>
            </div>
        @endif

        <div class="dropdown user-dropdown">
            <button class="user-btn dropdown-toggle" type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown"
                aria-expanded="false">
                <img src="{{ Config::getFile('user', auth()->user()->image, true) }}" alt="image">
                <span class="d-none d-md-inline-block">{{ Auth()->user()->username }}</span>
            </button>
            <ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
                <li class="d-md-none">
                    <span class="dropdown-item text-truncate">{{ Auth()->user()->username }}</span>
                </li>
                <li><a class="dropdown-item" href="{{ route('user.2fa') }}"><i class="far fa-user-circle me-2"></i>
                        {{ __('2FA') }}</a></li>
                <li><a class="dropdown-item" href="{{ route('user.profile') }}"><i class="fas fa-cog me-2"></i>
                        {{ __('Settings') }}</a></li>
                <li><a class="dropdown-item" href="{{ route('user.logout') }}"><i class="fas fa-sign-out-alt me-2"></i>
                        {{ __('Logout') }}</a></li>
            </ul>
        </div>
    </header>

    <main class="dashbaord-main">
        @yield('content')
    </main>
    <script src="{{ Config::jsLib('frontend', 'lib/jquery-3.6.0.min.js') }}"></script>
    <script src="{{ Config::jsLib('frontend', 'lib/bootstrap.bundle.min.js') }}"></script>
    <script src="{{ Config::jsLib('frontend', 'lib/slick.min.js') }}"></script>
    <script src="{{ Config::jsLib('frontend', 'lib/wow.min.js') }}"></script>
    <script src="{{ Config::jsLib('frontend', 'lib/jquery.countdown.min.js') }}"></script>
    <script src="{{ Config::jsLib('frontend', 'lib/jquery.basictable.min.js') }}"></script>
    <script src="{{ Config::jsLib('frontend', 'lib/glightbox.min.js') }}"></script>

    @stack('external-script')

    @if (Config::config()->alert === 'izi')
        <script src="{{ Config::jsLib('frontend', 'izitoast.min.js') }}"></script>
    @elseif(Config::config()->alert === 'toast')
        <script src="{{ Config::jsLib('frontend', 'toastr.min.js') }}"></script>
    @else
        <script src="{{ Config::jsLib('frontend', 'sweetalert.min.js') }}"></script>
    @endif

    <script src="{{ Config::jsLib('frontend', 'lib/jQuery-plugin-progressbar.js') }}"></script>

    <script src="{{ Config::jsLib('frontend', 'app.js') }}"></script>
    @stack('script')
    <script>
        'use strcit'
        var base_url = '{{ url('/') }}';

        $(".sp_dropdown > a").on("click", function() {
            $(this).parent(".sp_dropdown").toggleClass('active');
            $(this).parent(".sp_dropdown").children('.sidebar-sub-menu').slideToggle();
        });

        $('.sidebar-toggeler').on('click', function() {
            $('.user-sidebar').toggleClass('active');
        });

        $('.site-table').basictable({
            breakpoint: 1199
        });
        
        var url = "{{ route('change-language') }}";

        $(".change-lang").on('change', function() {
            console.log($(this).val())
            if ($(this).val() == '') {
                return false;
            }
            
            window.location.href = url + "?lang=" + $(this).val();
        });
    </script>

    @include('alert')
</body>

</html>
