@extends(Config::theme() . 'layout.auth')
@section('content')
    <div class="row gy-4">
        <div class="col-md-4">
            <div class="sp_card h-100">
                <div class="card-header">
                    <h5 class="mb-3">{{ __('User') }}</h5>
                    <input type="text" name="search" class="form-control" id="filter">
                </div>
                <div class="card-body p-0">
                    <ul class="user-chat-list" id="customer_fetch">
                        @foreach ($customers as $customer)
                            <li class="single-user-chat {{ $loop->first ? 'active' : '' }}" data-id="{{ $customer->id }}"
                                data-name="{{ $customer->username }}"
                                data-image="{{ Config::getFile('user', $customer->image, true) }}"
                                data-email="{{ $customer->email }}" data-route="">
                                <input type="radio" class="single-chat-field activeUser" value="{{ $customer->username }}"
                                    @if ($loop->first) checked @endif>
                                <div class="top">
                                    <img src="{{ Config::getFile('user', $customer->image, true) }}" alt="image">
                                    <div class="single-user-content">
                                        <div class="single-user-name-date">
                                            <h6 class="single-user-name">{{ $customer->username }}</h6>
                                            @if ($customer->sendMessage()->where('auction_id', $auction->id)->count() > 0)
                                                <span class="single-chat-date">
                                                    {{ $customer->sendMessage()->where('auction_id', $auction->id)->latest()->first()->created_at->format('H:i A') }}
                                                </span>
                                            @endif
                                        </div>

                                        @if ($customer->sendMessage()->where('auction_id', $auction->id)->count() > 0)
                                            <div class="single-user-last-message">
                                                <p class="last-message">
                                                    {{ $customer->sendMessage()->where('auction_id', $auction->id)->latest()->first()->message }}
                                                </p>
                                                @if ($customer->sendMessage()->where('read_at', null)->count() > 0)
                                                    <div class="single-user-last-message-status">
                                                        <span
                                                            class="message-count">{{ $customer->sendMessage()->where('auction_id', $auction->id)->where('read_at', null)->count() }}</span>

                                                    </div>
                                                @endif
                                            </div>
                                        @endif
                                    </div>
                                </div>
                            </li>
                        @endforeach
                    </ul>
                </div>
            </div>
        </div>

        <div class="col-md-8">
            <div class="sp_chat_wrapper customer_chat_wrapper">
                <div class="sp_chat_wrapper_header">
                    <div class="sp_user_left">
                        <img src="{{Config::getFile('user','', true)}}" id="image" alt="image">
                        <div class="content">
                            <h6 class="user_name mb-0" id="username"></h6>
                            <p class="mb-0" id="email"></p>
                        </div>
                    </div>
                    <div class="sp_user_right">

                    </div>
                </div>

                <div class="sp_chat_wrapper_body" id="messages_container">


                </div>
            </div>
        </div>
    </div>

    <div class="row justify-content-end">
        <div class="col-lg-8">
            <div class="customer_chat_box">
                <textarea cols="30" rows="10" placeholder="{{ __('Write Message') }}" class="message-field"
                    id="messsageInput"></textarea>
                <button type="submit" class="chat-message-btn">
                    {{ __('Send') }}<i class="far fa-paper-plane ms-2"></i>
                </button>
            </div>
        </div>
    </div>
@endsection

@push('style')
    <style>
        .chat-single {
            width: 52%;
            display: flex;
            margin: 30px 0;
        }

        @media (max-width: 991px) {
            .chat-single {
                width: 85%;
            }
        }

        @media (max-width: 575px) {
            .chat-single {
                width: 100%;
            }
        }

        .chat-single .thumb {
            width: 45px;
            height: 45px;
            overflow: hidden;
            border-radius: 50%;
        }

        .chat-single .thumb img {
            object-fit: cover;
            -o-object-fit: cover;
            width: 100%;
            height: 100%;
        }

        .chat-single .content {
            width: calc(100% - 45px);
            padding-left: 20px;
        }

        .chat-single .content_top {
            display: flex;
            flex-wrap: wrap;
            align-items: center;
            justify-content: space-between;
        }

        .chat-single .content_top .user_name {
            font-size: 14px;
            font-weight: 600;
            margin-bottom: 0;
        }

        .chat-single .content_message {
            padding: 15px 20px;
            margin-top: 8px;
            background-color: #000024;
            border-radius: 5px;
            margin-bottom: 0;
        }

        .chat-single.own-chat-single {
            float: right;

        }

        .chat-single.own-chat-single .content {
            order: -1;
            padding-left: 0;
            padding-right: 20px;
        }

        .chat-single.own-chat-single .content_top {
            flex-direction: row-reverse;
        }

        .chat-single.own-chat-single .content_message {
            background: var(--main-color);
            color: #fff;
        }

        /* user chat list css */
        .sp_chat_wrapper {
            display: flex;
            flex-flow: column;
            background-color: var(--main-color-two);
            border-radius: 10px;
            box-shadow: var(--box-shadow);
            height: 100%;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header {
            display: flex;
            flex-wrap: wrap;
            align-items: center;
            justify-content: space-between;
            border-bottom: 1px solid #ffffff14;
            padding: 10px 0;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header .sp_user_left {
            padding: 5px 20px;
            display: flex;
            align-items: center;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header .sp_user_left img {
            width: 42px;
            height: 42px;
            border-radius: 50%;
            object-fit: cover;
            -o-object-fit: cover;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header .sp_user_right button {
            border: none;
            background-color: transparent;
            font-size: 20px;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header .sp_user_left .content {
            padding-left: 15px;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header .sp_user_left .user_name {
            font-size: 16px;
            font-weight: 600;
        }

        .sp_chat_wrapper .sp_chat_wrapper_header .sp_user_right {
            padding: 5px 20px;
        }

        .sp_chat_wrapper .sp_chat_wrapper_body {
            flex-grow: 1;
            padding: 20px;
            max-height: 530px;
            overflow-y: auto;
        }

        .sp_chat_wrapper .sp_chat_wrapper_body::-webkit-scrollbar {
            width: 12px;
        }

        .sp_chat_wrapper .sp_chat_wrapper_body::-webkit-scrollbar-track {
            background: var(--main-color-two);
        }

        .sp_chat_wrapper .sp_chat_wrapper_body::-webkit-scrollbar-thumb {
            background-color: #ffffff14;
            border-radius: 20px;
            border: 3px solid var(--main-color-two);
        }

        .sp_chat_wrapper .sp_chat_wrapper_footer {
            padding: 20px;
            border-top: 1px solid #ffffff14;
            position: relative;
        }

        .sp_chat_wrapper .sp_chat_wrapper_footer .message-field {
            height: 50px;
            width: 100%;
            resize: none;
            border: 1px solid #ffffff14;
            border-radius: 10px;
            padding: 10px 15px;
            padding-right: 105px;
        }

        .sp_chat_wrapper .sp_chat_wrapper_footer .message-field:focus {
            border-color: var(--main-color);
        }

        .sp_chat_wrapper .sp_chat_wrapper_footer .chat-message-btn {
            position: absolute;
            bottom: 36px;
            right: 30px;
            background-color: var(--main-color);
            border: none;
            padding: 5px 15px;
            z-index: 1;
            transition: all 0.3s;
            color: #fff;
            border-radius: 5px;
        }

        .sp_chat_wrapper .sp_chat_wrapper_footer .chat-message-btn::before {
            position: absolute;
            content: '';
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: var(--primary);
            z-index: -1;
            border-radius: 5px;
            transition: all 0.3s;
        }

        .no-chatting {
            text-align: center;
        }

        .no-chatting {
            padding: 20px 0;
        }

        .no-chatting i {
            font-size: 62px;
        }

        .no-chatting p {
            font-size: 18px;
        }

        .sp_chat_wrapper.customer_chat_wrapper {
            border-radius: 10px 10px 0 0;
        }

        .customer_chat_box {
            padding: 20px;
            border-top: 1px solid #ffffff14;
            border-radius: 0 0 10px 10px;
            background-color: var(--main-color-two);
            position: relative;
        }

        .customer_chat_box .message-field {
            height: 100px;
            border: 1px solid #ffffff14;
            border-radius: 10px;
            padding: 10px 20px;
            padding-right: 100px
        }

        .customer_chat_box .chat-message-btn {
            position: absolute;
            bottom: 30px;
            right: 30px;
            padding: 6px 15px;
            background-color: var(--main-color);
            border-radius: 8px;
            color: #fff;
        }



        /* user chat list css */
        .user-chat-list {
            max-height: 690px;
            overflow-y: auto;
        }

        .user-chat-list::-webkit-scrollbar {
            width: 12px;
        }

        .user-chat-list::-webkit-scrollbar-track {
            background: var(--main-color-two);
        }

        .user-chat-list::-webkit-scrollbar-thumb {
            background-color: #ffffff14;
            border-radius: 20px;
            border: 3px solid var(--main-color-two);
        }

        .single-user-chat {
            display: flex;
            flex-wrap: wrap;
            position: relative;
            padding: 15px 20px;
            border-bottom: 1px solid #ffffff14;
            z-index: 1;
        }

        .single-user-chat::before {
            position: absolute;
            content: '';
            background-color: var(--main-color);
            opacity: 0;
            width: 100%;
            height: 100%;
            top: 0;
            left: 0;
            z-index: -1;
            transition: all 0.3s;
        }

        .single-user-chat.active::before {
            opacity: 0.15;
        }

        .single-user-chat::after {
            position: absolute;
            content: '';
            background-color: var(--main-color);
            opacity: 0;
            width: 2px;
            height: 100%;
            top: 0;
            left: 0;
            z-index: -1;
            transition: all 0.3s;
        }

        .single-user-chat.active::after {
            opacity: 1;
        }

        .single-user-chat:last-child {
            border-bottom: none;
        }

        .single-user-chat .single-chat-field {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            opacity: 0;
            z-index: 1;
            cursor: pointer;
        }

        .single-user-chat .top {
            display: flex;
            padding-right: 15px;
            width: 100%;
            align-items: center;
        }

        .single-user-chat .top img {
            width: 42px;
            height: 42px;
            border-radius: 50%;
            object-fit: cover;
            -o-object-fit: cover;
        }

        .single-user-chat .single-user-content {
            width: calc(100% - 42px);
            padding-left: 15px;
        }

        .single-user-name-date {
            display: flex;
            align-items: center;
            justify-content: space-between;
            margin-bottom: 3px;
        }

        .single-user-name-date .single-chat-date {
            font-size: 13px;
        }

        .single-user-chat .single-user-content .single-user-name {
            font-weight: 600;
            color: #fff;
            margin-bottom: 0;
            font-size: 15px;
        }

        .single-user-last-message {
            display: flex;
            align-items: center;
            justify-content: space-between;
        }

        .single-user-chat .single-user-content .last-message {
            display: -webkit-box;
            -webkit-line-clamp: 1;
            -webkit-box-orient: vertical;
            overflow: hidden;
            text-overflow: ellipsis;
            margin-bottom: 0;
            font-size: 13px;
            width: calc(100% - 30px);
        }

        .single-user-last-message .single-user-last-message-status .message-count {
            width: 17px;
            height: 17px;
            background-color: red;
            border-radius: 50%;
            color: #fff;
            font-size: 11px;
            font-weight: 500;
            display: inline-flex;
            justify-content: center;
            align-items: center;
        }

        .single-user-last-message .single-user-last-message-status .message-seen {
            color: green;
            font-size: 18px;
        }

        @media screen and (max-width: 1399px) {
            .chat-single {
                width: 80%;
            }
        }

        @media screen and (max-width: 767px) {
            .user-chat-list {
                max-height: 200px;
            }

            .chat-single {
                width: 100%;
            }

            .chat-single .thumb {
                width: 35px;
                height: 35px;
            }

            .chat-single .content {
                width: calc(100% - 35px);
                padding-left: 15px;
            }

            .chat-single .content_message {
                padding: 15px;
                font-size: 13px;
            }

            .chat-single.own-chat-single .content_top .user_name {
                font-size: 13px;
            }

            .chat-single.own-chat-single .content_top span {
                font-size: 12px;
            }

        }
    </style>
@endpush



@push('script')
    <script>
        'use strict'

        function scrollPaubos() {
            var a = document.getElementById('messages_container');
            a.scrollTop = a.scrollHeight;
        }


        $(document).on('keyup', "#filter", function() {
            var filter = $(this).val(),
                count = 0;
            $(".single-user-chat").each(function() {
                if ($(this).attr('data-name').search(new RegExp(filter, "i")) < 0) {
                    $(this).fadeOut();
                } else {
                    $(this).show();
                    count++;
                }
            });
        });


        loadMessagesOfThisConvo($('.single-user-chat.active').data('id'));

        $('#image').attr('src', $('.single-user-chat.active').data('image'))
        $('#username').html($('.single-user-chat.active').data('name'))
        $('#email').html($('.single-user-chat.active').data('email'))
        $('#route').attr('data-route', $('.single-user-chat.active').data('route'))
        $('.chat-message-btn').attr('data-id', $('.single-user-chat.active').data('id'))

        $(".single-user-chat").each(function() {
            $(this).on("click", function() {
                if ($(this).siblings(".single-user-chat").hasClass("active")) {
                    $(this).siblings(".single-user-chat").removeClass("active");
                    $(this).addClass("active");
                } else {
                    $(this).addClass("active");
                }


                $('#image').attr('src', $(this).data('image'))
                $('#username').html($(this).data('name'))
                $('#email').html($(this).data('email'))
                $('#route').attr('data-route', $('.single-user-chat.active').data('route'))
                $('.chat-message-btn').attr('data-id', $('.single-user-chat.active').data('id'))

                loadMessagesOfThisConvo($('.single-user-chat.active').data('id'));

            });
        })


        setInterval(() => {
            loadMessagesOfThisConvo($('.single-user-chat.active').data('id'))
        }, 5000);


        function loadMessagesOfThisConvo(id) {

            $.ajax({
                method: 'GET',
                url: "{{ url()->current() }}",
                data: {
                    customer: id
                },
                success: function(response) {

                    $('#messages_container').html(response)

                }
            });
        }


        $(document).on('click', '#route', function() {
            const modal = $('#deleteMessage')

            modal.find('form').attr('action', $(this).data('route'))

            modal.modal('show')
        })


        $(document).on('click', '.chat-message-btn', function() {
            $.ajax({
                method: 'POST',
                url: "{{ url()->current() }}",
                data: {
                    auction: "{{ $auction->id }}",
                    message: $('#messsageInput').val(),
                    customer: $('.single-user-chat.active').data('id'),
                    _token: "{{ csrf_token() }}"
                },
                success: function(response) {
                    loadMessagesOfThisConvo($('.single-user-chat.active').data('id'))
                },
                error: function(response) {
                 
                    @if (Config::config()->alert === 'izi')
                        iziToast.error({
                            position: 'topRight',
                            message: JSON.parse(response.responseText).errors.message[0],
                        });
                    @elseif (Config::config()->alert === 'toast')
                        toastr.error(JSON.parse(response.responseText).errors.message[0], {
                            positionClass: "toast-top-right"

                        })
                    @else
                        Swal.fire({
                            icon: 'error',
                            title: JSON.parse(response.responseText).errors.message[0]
                        })
                    @endif

                }
            });
            $('#messsageInput').val('');

        })
    </script>
@endpush
