@extends(Config::theme() . 'layout.auth')
@section('content')
    <div class="row">
        <div class="col-md-12">
            <div class="sp_card">
                <div class="card-header">
                    <div class="card-header-items">
                        <div class="card-header-item"> 
                            <div class="tab-btn-group">
                                <a class="tab-btn {{ Request::routeIs('user.withdraw.all') ? 'active' : '' }}"
                                    href="{{ route('user.withdraw.all') }}">{{ __('All Withdraw') }}</a>

                                <a class="tab-btn {{ Request::routeIs('user.withdraw.pending') ? 'active' : '' }}"
                                    href="{{ route('user.withdraw.pending') }}">{{ __('Pending Withdraw') }}</a>

                                <a class="tab-btn {{ Request::routeIs('user.withdraw.complete') ? 'active' : '' }}"
                                    href="{{ route('user.withdraw.complete') }}">{{ __('Complete Withdraw') }}</a>
                            </div>
                        </div>
                        <div class="card-header-item">
                            <form action="{{ url()->current() }}" method="get" class="row justify-content-md-end g-3">
                                <div class="col-auto">
                                    <input type="text" name="trx" class="form-control form-control-sm me-2"
                                        placeholder="transaction id">
                                </div>
                                <div class="col-auto">
                                    <input type="date" class="form-control form-control-sm me-3" 
                                        name="date">
                                </div>
                                <div class="col-auto">
                                    <button type="submit" class="btn btn-sm grad-btn">{{ __('Search') }}</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                <div class="card-body p-0">
                    <div class="table-responsive">
                        <table class="table site-table">
                            <thead>
                                <tr>
                                    <th>{{ __('Trx') }}</th>
                                    <th>{{ __('Date') }}</th>
                                    <th>{{ __('Method Name') }}</th>
                                    <th>{{ __('Withdraw Amount') }}</th>
                                    <th>{{ __('Charge') }}</th>
                                    <th>{{ __('Getable Amount') }}</th>
                                    <th>{{ __('Charge Type') }}</th>
                                    <th>{{ __('status') }}</th>
                                    <th>{{ __('Action') }}</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($withdrawlogs as $key => $withdrawlog)
                                    <tr>
                                        <td>{{ $withdrawlog->trx }}</td>
                                        <td>
                                            {{ __($withdrawlog->created_at->format('d F Y')) }}
                                        </td>
                                        <td>
                                            {{ __(optional($withdrawlog->withdrawMethod)->name) }}</td>
                                        <td>
                                            {{ Config::formatter($withdrawlog->withdraw_amount) }}
                                        </td>
                                        <td>
                                            {{ Config::formatter($withdrawlog->withdraw_charge) }}
                                        </td>
                                        <td>
                                            {{ Config::formatter($withdrawlog->total) }}
                                        </td>
                                        <td>
                                            {{ ucwords(optional($withdrawlog->withdrawMethod)->type) }}
                                        </td>

                                        <td>
                                            @if ($withdrawlog->status == 1)
                                                <span class="badge badge-success">{{ __('Success') }}</span>
                                            @elseif($withdrawlog->status == 2)
                                                <span class="badge badge-danger">{{ __('Rejected') }}</span>
                                            @else
                                                <span class="badge badge-warning">{{ __('Pending') }}</span>
                                            @endif
                                        </td>
                                        <td>
                                            <button class="view-btn details"
                                                data-user_data="{{ json_encode($withdrawlog->proof) }}"
                                                data-withdraw="{{ $withdrawlog }}"><i
                                                    class="far fa-eye"></i></button>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-center" colspan="100%">
                                            {{ __('No Data Found') }}
                                        </td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($withdrawlogs->hasPages())
                    <div class="card-footer">
                        {{ $withdrawlogs->links() }}
                    </div>
                @endif
            </div>
        </div>
    </div>
  
    <div class="modal fade" id="details" tabindex="-1" role="dialog"  aria-hidden="true">
        <div class="modal-dialog modal-lg" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">{{ __('Withdraw Details') }}</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close">
                    </button>
                </div>
                <div class="modal-body">
                    <div class="withdraw-details">
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-sm btn-danger"
                        data-bs-dismiss="modal">{{ __('Close') }}</button>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('script')
    <script>
        
        'use strict'

        $(function() {

            $('.details').on('click', function() {
                const modal = $('#details');

                let html = `

                    <ul class="list-group">
                            <li class="list-group-item  d-flex justify-content-between align-items-center">
                               {{ __('Withdraw Email') }}
                                <span>${$(this).data('user_data').email}</span>
                            </li>
                            <li class="list-group-item  d-flex justify-content-between align-items-center">
                                {{ __('Withdraw Account Information') }}
                                <span>${$(this).data('user_data').account_information}</span>
                            </li>


                            <li class="list-group-item  d-flex justify-content-between align-items-center">
                                {{ __('Note For Withdraw') }}
                                <span>${$(this).data('user_data').note}</span>
                            </li>

                            <li class="list-group-item  d-flex justify-content-between align-items-center">
                                {{ __('Withdraw Transaction') }}
                                <span>${$(this).data('withdraw').trx}</span>
                            </li>
                            
                            <li class="list-group-item  d-flex justify-content-between align-items-center">
                                {{ __('Withdraw Reject Reason') }}
                                <span>${$(this).data('withdraw').reject_reason}</span>
                            </li>
                        </ul>
                `;

                modal.find('.withdraw-details').html(html);
                modal.modal('show');
            })

        })
    </script>
@endpush
