<?php

use App\Http\Controllers\AuctionController;
use App\Http\Controllers\Auth\FacebookController;
use App\Http\Controllers\Auth\ForgotPasswordController;
use App\Http\Controllers\Auth\GoogleController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\Auth\RegistrationController;
use App\Http\Controllers\Backend\IsoStageController;
use App\Http\Controllers\DepositController;
use App\Http\Controllers\FrontendController;
use App\Http\Controllers\KycController;
use App\Http\Controllers\LogController;
use App\Http\Controllers\LoginSecurityController;
use App\Http\Controllers\PaymentController;
use App\Http\Controllers\PayoutController;
use App\Http\Controllers\TicketController;
use App\Http\Controllers\TokenContributeController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\ChatController;
use Illuminate\Support\Facades\Route;


Route::get('admin', function () {
    return redirect()->route('admin.login');
});

Route::name('user.')->group(function () {

    

    Route::middleware('guest')->group(function () {
        Route::get('register/{reffer?}', [RegistrationController::class, 'index'])->name('register')->middleware('reg_off');
        Route::post('register/{reffer?}', [RegistrationController::class, 'register'])->middleware('reg_off');

        Route::get('login', [LoginController::class, 'index'])->name('login');
        Route::post('login', [LoginController::class, 'login']);

        Route::get('auth/facebook', [FacebookController::class, 'redirectToFacebook'])->name('facebook.login');
        Route::get('auth/facebook/callback', [FacebookController::class, 'handleFacebookCallback']);


        Route::get('auth/google', [GoogleController::class, 'redirectToGoogle'])->name('google.login');
        Route::get('auth/google/callback', [GoogleController::class, 'handleGoogleCallback']);

        Route::get('forgot/password', [ForgotPasswordController::class, 'index'])->name('forgot.password');
        Route::post('forgot/password', [ForgotPasswordController::class, 'sendVerification']);
        Route::get('verify/code', [ForgotPasswordController::class, 'verify'])->name('auth.verify');
        Route::post('verify/code', [ForgotPasswordController::class, 'verifyCode']);
        Route::get('reset/password', [ForgotPasswordController::class, 'reset'])->name('reset.password');
        Route::post('reset/password', [ForgotPasswordController::class, 'resetPassword']);

        Route::get('verify/email', [LoginController::class, 'emailVerify'])->name('email.verify');
        Route::post('verify/email', [LoginController::class, 'emailVerifyConfirm'])->name('email.verify');
    });

    Route::middleware(['auth', 'inactive', 'is_email_verified'])->group(function () {




        Route::get('2fa', [LoginSecurityController::class, 'show2faForm'])->name('2fa');
        Route::post('2fa/generateSecret', [LoginSecurityController::class, 'generate2faSecret'])->name('generate2faSecret');
        Route::post('2fa/enable2fa', [LoginSecurityController::class, 'enable2fa'])->name('enable2fa');
        Route::post('2fa/disable2fa', [LoginSecurityController::class, 'disable2fa'])->name('disable2fa');
        Route::post('2fa/2faVerify', function () {
            return redirect(URL()->previous());
        })->name('2faVerify')->middleware('2fa');

        Route::get('authentication-verify', [ForgotPasswordController::class, 'verifyAuth'])->name('authentication.verify')->withoutMiddleware('is_email_verified');

        Route::post('authentication-verify/email', [ForgotPasswordController::class, 'verifyEmailAuth'])->name('authentication.verify.email')->withoutMiddleware('is_email_verified');

        Route::post('authentication-verify/sms', [ForgotPasswordController::class, 'verifySmsAuth'])->name('authentication.verify.sms')->withoutMiddleware('is_email_verified');

        Route::get('logout', [LoginController::class, 'signOut'])->name('logout');

        Route::get('kyc', [KycController::class, 'kyc'])->name('kyc');
        Route::post('kyc', [KycController::class, 'kycUpdate']);

    

        Route::middleware('2fa', 'kyc')->group(function () {

            Route::get('dashboard', [UserController::class, 'dashboard'])->name('dashboard');
            
            Route::get('{user}/profile',[UserController::class,'user_visit_profile'])->name('user_visit_profile');
            Route::get('auctions',[AuctionController::class,'index'])->name('auction.index');
            Route::get('auctions/{code}',[AuctionController::class,'details'])->name('auction.details');
    
            Route::get('auctions/message/{code}',[AuctionController::class,'auctionMessage'])->name('auction.message');
            Route::post('auctions/message/{code}',[AuctionController::class,'auctionMessageStore']);
    
            Route::get('auction/create',[AuctionController::class,'create'])->name('auction.create');
            Route::post('auction/store',[AuctionController::class,'store'])->name('auction.store');
    
            Route::get('message',[UserController::class,'chat'])->name('get.message');
            Route::post('message',[UserController::class,'chatStore']);
    
    
            Route::get('stages',[IsoStageController::class,'allStages'])->name('stages');
    
            Route::post('auction/transection/store',[AuctionController::class,'auctionTransectionStore'])->name('auction.transection.store');
            Route::get('auction/withdraw/{id}',[AuctionController::class,'auctionWithdraw'])->name('auction.withdraw');

            Route::get('profile/setting', [UserController::class, 'profile'])->name('profile');
            Route::post('profile/setting', [UserController::class, 'profileUpdate'])->name('profileupdate');
            Route::get('profile/change/password', [UserController::class, 'changePassword'])->name('change.password');
            Route::post('profile/change/password', [UserController::class, 'updatePassword'])->name('update.password');

       
            Route::get('contribute',[TokenContributeController::class,'contribute'])->name('contribute');
            Route::post('contribute/store',[TokenContributeController::class,'store'])->name('contribute.store');
            Route::get('currency-convert',[TokenContributeController::class,'convert'])->name('currency.convert');
            Route::get('currency-symbol',[TokenContributeController::class,'symbol'])->name('currency.symbol');

            Route::get('withdraw', [PayoutController::class, 'withdraw'])->name('withdraw');
            Route::get('withdraw/all', [LogController::class, 'allWithdraw'])->name('withdraw.all');
            Route::get('withdraw/pending', [LogController::class, 'pendingWithdraw'])->name('withdraw.pending');
            Route::get('withdraw/complete', [LogController::class, 'completeWithdraw'])->name('withdraw.complete');
            Route::post('withdraw', [PayoutController::class, 'withdrawCompleted']);
            Route::get('withdraw/fetch/{id}', [PayoutController::class, 'withdrawFetch'])->name('withdraw.fetch');
            Route::get('return/interest', [PayoutController::class, 'returnInterest'])->name('returninterest');


            Route::resource('ticket', TicketController::class);
            Route::post('ticket/reply', [TicketController::class, 'reply'])->name('ticket.reply');
            Route::get('ticket/reply/status/change/{id}', [TicketController::class, 'statusChange'])->name('ticket.status-change');

            Route::get('ticket/status/{status}', [TicketController::class, 'ticketStatus'])->name('ticket.status');

            Route::get('ticket/attachement/{id}', [TicketController::class, 'ticketDownload'])->name('ticket.download');

            Route::match(['get', 'post'], '/payments/crypto/pay', Victorybiz\LaravelCryptoPaymentGateway\Http\Controllers\CryptoPaymentController::class)->name('payments.crypto.pay');
            Route::post('/payments/crypto/callback', [GourlProcessController::class, 'callback'])->withoutMiddleware(['web', 'auth']);
          

            

            Route::get('gateways/{id}', [PaymentController::class, 'gateways'])->name('gateways');

            Route::post('paynow/{id}', [PaymentController::class, 'paynow'])->name('paynow');

            Route::get('gateways/{id}/details', [PaymentController::class, 'gatewaysDetails'])->name('gateway.details');

            Route::post('gateways/{id}/details', [PaymentController::class, 'gatewayRedirect']);

            Route::any('payment-success/{gateway}', [PaymentController::class, 'paymentSuccess'])->name('payment.success');


            Route::get('stages/log',[LogController::class,'stage_log'])->name('stage_log');
            Route::get('auctions/log/{status}',[LogController::class,'auction_log'])->name('auction_log');
            
            Route::get('invest/all', [UserController::class, 'allInvest'])->name('invest.all');
            Route::get('invest/pending', [UserController::class, 'pendingInvest'])->name('invest.pending');
            Route::get('invest/log', [LogController::class, 'investLog'])->name('invest.log');

 
            Route::get('transaction/log', [LogController::class, 'transactionLog'])->name('transaction.log');

            Route::get('interest/log', [UserController::class, 'interestLog'])->name('interest.log');


            Route::get('deposit', [DepositController::class, 'deposit'])->name('deposit');

            Route::get('deposit/log', [LogController::class, 'depositLog'])->name('deposit.log');

            Route::get('commision', [LogController::class, 'Commision'])->name('commision');

            Route::get('subscription-log', [LogController::class, 'subscriptionLog'])->name('subscription');

            Route::get('refferal', [LogController::class, 'refferalLog'])->name('refferalLog');

            
            Route::get('vouguepay/success', [VouguepayProcessController::class, 'returnSuccess'])->name('vouguepay.redirect');
       
            Route::get('chat',[ChatController::class,'index'])->name('chat.index');
            



        });
    });
});

Route::get('/', [FrontendController::class, 'index'])->name('home');


Route::get('download/white-paper',[FrontendController::class,'download'])->name('paper.download');
Route::get('cookie/details',[FrontendController::class,'cookies'])->name('cookies');
Route::get('change-language', [FrontendController::class, 'changeLanguage'])->name('change-language');

Route::get('/blog/{id}/{slug}', [FrontendController::class, 'blogDetails'])->name('blog.details');

Route::get('links/{id}/{slug}', [FrontendController::class, 'linksDetails'])->name('links');

Route::post('subscribe', [FrontendController::class, 'subscribe'])->name('subscribe');
Route::post('contact', [FrontendController::class, 'contactSend'])->name('contact');
Route::get('{pages}', [FrontendController::class, 'page'])->name('pages');
